API Reference
=============

This section contains the complete API reference for NPAP.

.. toctree::
   :maxdepth: 2

   managers
   interfaces
   partitioning
   aggregation
   exceptions

Core Module
-----------

.. currentmodule:: npap

.. autosummary::
   :toctree: generated
   :nosignatures:

   PartitionAggregatorManager
   AggregationProfile
   AggregationMode
   PartitionResult
   get_mode_profile
